.. -*-restructuredtext-*-

.. image:: https://travis-ci.org/ubernostrum/pwned-passwords-django.svg?branch=master
    :target: https://travis-ci.org/ubernostrum/pwned-passwords-django

pwned-passwords-django provides helpers for working with the `Pwned
Passwords database of Have I Been Pwned
<https://haveibeenpwned.com/Passwords>`_ in `Django
<https://www.djangoproject.com/>`_ powered sites. Pwned Passwords is
an extremely large database of passwords known to have been
compromised through data breaches, and is useful as a tool for
rejecting common or weak passwords.

Documentation is `available online
<https://pwned-passwords-django.readthedocs.io/>`_.
